########
profiles
########

.. toctree::
   :maxdepth: 1

   opentype
   universal
   adobefonts
   googlefonts
   notofonts
   fontbureau
   fontwerk
   fontval
   ufo
   iso15008
   outline
   shaping
